@@ -1,4 +1,4 @@
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -23,6 +23,7 @@ class ImportSorter:
         self.config = config
         self.module = module
         self.path = path
+        self.warning_nodes: List[Tuple[cst.CSTNode, str]] = []
         self.warnings: List[SortWarning] = []
         self.wrapper = cst.MetadataWrapper(module)
         self.transformer = ImportSortingTransformer(config, module, self)
@@ -110,10 +111,9 @@ class ImportSorter:
         for key, value in imp.imported_names.items():
             shadowed = block.imported_names.get(key)
             if shadowed and shadowed != value:
-                line = self.transformer.get_line(imp.node)
-                self.warnings.append(
-                    SortWarning(
-                        line,
+                self.warning_nodes.append(
+                    (
+                        imp.node,
                         f"Name {shadowed!r} shadowed by {value!r}; "
                         "implicit block split",
                     )
@@ -302,12 +302,19 @@ class ImportSorter:
     def sort_module(self) -> cst.Module:
         with timed(f"sorting {self.path}"):
             new_module = self.wrapper.visit(self.transformer)
+            if self.warning_nodes:
+                positions = self.wrapper.resolve(PositionProvider)
+                self.warnings = [
+                    SortWarning(
+                        positions[self.transformer.get_original_node(node)].start.line,
+                        msg,
+                    )
+                    for (node, msg) in self.warning_nodes
+                ]
             return new_module
 
 
 class ImportSortingTransformer(cst.CSTTransformer):
-    METADATA_DEPENDENCIES = (PositionProvider,)
-
     def __init__(
         self, config: Config, module: cst.Module, sorter: ImportSorter
     ) -> None:
@@ -315,20 +322,11 @@ class ImportSortingTransformer(cst.CSTTransformer):
         self.module = module
         self.sorter = sorter
         self.statement_map: Dict[cst.CSTNode, cst.SimpleStatementLine] = {}
+        self.default_indent: str = module.default_indent
+        self.indent: str = ""
 
-    def get_line(self, node: cst.CSTNode) -> int:
-        if node in self.statement_map:
-            pos = self.get_metadata(PositionProvider, self.statement_map[node])
-        else:
-            pos = self.get_metadata(PositionProvider, node)
-
-        return pos.start.line
-
-    def get_indent(self, node: cst.CSTNode) -> str:
-        pos = self.get_metadata(PositionProvider, node)
-        indent_level = pos.start.column
-        indent = self.module.default_indent[0] * indent_level
-        return indent
+    def get_original_node(self, node: cst.CSTNode) -> cst.CSTNode:
+        return self.statement_map.get(node, node)
 
     def leave_SimpleStatementLine(
         self,
@@ -341,17 +339,24 @@ class ImportSortingTransformer(cst.CSTTransformer):
     def leave_Module(
         self, original_node: cst.Module, updated_node: cst.Module
     ) -> cst.Module:
-        indent = self.get_indent(original_node)
         sorted_body = self.sorter.find_and_sort_blocks(
-            updated_node.body, module=self.module, indent=indent
+            updated_node.body, module=self.module, indent=""
         )
         return updated_node.with_changes(body=sorted_body)
 
+    def visit_IndentedBlock(self, node: cst.IndentedBlock) -> Optional[bool]:
+        node_indent = node.indent
+        self.indent += self.default_indent if node_indent is None else node_indent
+        return True
+
     def leave_IndentedBlock(
         self, original_node: cst.IndentedBlock, updated_node: cst.IndentedBlock
     ) -> cst.BaseSuite:
-        indent = self.get_indent(original_node)
+        node_indent = original_node.indent
+        if node_indent is None:
+            node_indent = self.default_indent
         sorted_body = self.sorter.find_and_sort_blocks(
-            updated_node.body, module=self.module, indent=indent
+            updated_node.body, module=self.module, indent=self.indent
         )
+        self.indent = self.indent[: -len(node_indent)]
         return updated_node.with_changes(body=sorted_body)
