@@ -1,4 +1,4 @@
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -564,6 +564,18 @@ numpy = ["numpy", "pandas"]
             """,
         )
 
+    def test_single_line_parens(self) -> None:
+        self.assertUsortResult(
+            """
+                from delta import echo, foxtrot
+                from alfa import (bravo, charlie)  # hello
+            """,
+            """
+                from alfa import bravo, charlie  # hello
+                from delta import echo, foxtrot
+            """,
+        )
+
     def test_single_line_import_long_comment(self) -> None:
         """
         Basic import statements can't be reflowed to multiple lines
